@@ -3,7 +3,7 @@ package Plack::Middleware::XSRFBlock;
 {
   $Plack::Middleware::XSRFBlock::DIST = 'Plack-Middleware-XSRFBlock';
 }
-$Plack::Middleware::XSRFBlock::VERSION = '0.0.12';
+$Plack::Middleware::XSRFBlock::VERSION = '0.0.13';
 use strict;
 use warnings;
 use parent 'Plack::Middleware';
@@ -12,6 +12,7 @@ use parent 'Plack::Middleware';
 use Digest::HMAC_SHA1 'hmac_sha1_hex';
 use HTTP::Status qw(:constants);
 
+use Plack::Request;
 use Plack::Response;
 use Plack::Util;
 use Plack::Util::Accessor qw(
@@ -328,7 +329,7 @@ sub xsrf_detected {
     $self->log(error => 'XSRF detected, returning HTTP_FORBIDDEN');
 
     if (my $app_for_blocked = $self->blocked) {
-        return $app_for_blocked->($env, $@, app => $self->app);
+        return $app_for_blocked->($env, $msg, app => $self->app);
     }
 
     return [
@@ -377,7 +378,7 @@ Plack::Middleware::XSRFBlock - Block XSRF Attacks with minimal changes to your a
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
 =head1 SYNOPSIS
 
@@ -629,7 +630,7 @@ L<Plack>
 
 ## BUILD STATUS
 
-[![Build status](https://badge.buildkite.com/330e67514dd501f1827bcf33db423ccadf201caf5b2b563fbf.svg)](https://buildkite.com/chizography/plack-middleware-xsrfblock)
+[![Build Status](https://travis-ci.org/chiselwright/plack-middleware-xsrfblock.svg?branch=master)](https://travis-ci.org/chiselwright/plack-middleware-xsrfblock)
 
 =end markdown
 
